/*
   This program adds a number to every value read from
   standard input and writes the result to standard output.

   The default value to add to every input number is 0.
   This default value can be overridden by
      1.) a value from a configuration file, or by
      2.) an environment variable, or by
      3.) a command line argument.
*/
import java.io.File;
import java.io.FileNotFoundException;
import java.util.Scanner;

public class Incrementor
{
   public static void main(String[] args)
   {
      // Set the default value.
      int incBy = 0;

      // Override the default value with a value from the configuration file.
      try
      {
         Scanner fileInput = new Scanner( new File("incrementor.cfg") );
         if (fileInput.hasNextInt())
         {
            // get an operand from the configuration file
            incBy = fileInput.nextInt();
         }
      }
      catch (FileNotFoundException e)
      {  // ignore the configuration file
      }

      // Override the default value with an environment variable value.
      String op;
      if ( (op = System.getenv( "IncrementorValue" )) != null )
      {
         try
         {  // get an operand from the environment
            incBy = Integer.parseInt(op);
         }
         catch (NumberFormatException e)
         {  // ignore this environment variable
         }
      }

      // Get a command line argument (if it exists).
      if (args.length > 0)
      {
         try
         {  // get an operand from the command line
            incBy = Integer.parseInt(args[0]);
         }
         catch (NumberFormatException e)
         {  // ignore this command line argument
         }
      }

      // Process the stream of input numbers.
      Scanner sc = new Scanner( System.in );
      while( sc.hasNextDouble() )
      {
         double x = sc.nextDouble();
         System.out.printf("%.1f ",  (x + incBy));
      }
   }
}
